"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Page = void 0;
const _1 = require(".");
const renderer_1 = __importDefault(require("../renderer"));
class Page extends _1.Model {
    static upsert(page) {
        const insert = _1.db(Page.tableName).insert(page);
        const update = _1.db.queryBuilder().update(page);
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        return Promise.resolve(_1.db.raw('? ON CONFLICT (name, wiki_name) DO ? returning *', [insert, update]).get('rows').get(0));
    }
    static getRandomRuPageName() {
        // eslint-disable-next-line
        return Promise.resolve(_1.db.raw('SELECT name FROM wikidot_ru_random_page_view').then((r) => r.rows[0].name));
    }
    static getRenderedPage(wikiName, pageName) {
        return __awaiter(this, void 0, void 0, function* () {
            const page = yield Page
                .query()
                .where({ wikiName: wikiName, name: pageName })
                .first();
            if (!page) {
                return null;
            }
            page.content = renderer_1.default({ name: pageName }, page.content);
            return page;
        });
    }
}
exports.Page = Page;
Page.tableName = 'pages';
Page.relationMappings = {
    branch: {
        relation: _1.Model.BelongsToOneRelation,
        modelClass: _1.Branch,
        join: {
            from: 'pages.wikiName',
            to: 'branches.name',
        },
    },
};
//# sourceMappingURL=page.js.map