"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const models_1 = require("../models");
const PAGE_NAME_BLACKLIST = /^(admin|nav|css|system):/;
function run(ctx, wikiName, pageName) {
    if (!(wikiName && pageName)) {
        throw new Error('Wiki name & page name are required');
    }
    const wiki = ctx.config.wikidotSites.find((site) => site.name === wikiName);
    if (!wiki) {
        throw new Error(`Unknown site "${wikiName}"`);
    }
    const wikiUrl = wiki.url;
    if (PAGE_NAME_BLACKLIST.test(pageName)) {
        return Promise.resolve();
    }
    ctx.log(`Importing page ${wikiName}/${pageName}`);
    return ctx.wk.fetchPage(wikiName, pageName)
        .catch((error) => {
        ctx.reportError('Error importing page', error, { wikiName, pageName });
    })
        .then((data) => models_1.Page.upsert({
        wikiName,
        name: pageName,
        title: data.title,
        content: data.content,
        tags: data.tags,
        rating: data.rating,
        html: data.html,
        createdAt: data.created_at,
        createdBy: data.created_by,
        updatedAt: data.updated_at,
        updatedBy: data.updated_by,
    }))
        .then(() => ctx.wk.fetchPageVotes(wikiUrl, pageName))
        .then((votes) => {
        ctx.log(`Imported votes for ${wikiName}/${pageName}`, { extra: votes });
        return models_1.Page.upsert({
            wikiName,
            name: pageName,
            votes: JSON.stringify(votes),
        });
    })
        .then(() => {
        ctx.log(`[DONE] ${wikiName}/${pageName}`);
    })
        .catch((error) => {
        ctx.reportError('Error saving page', error, { wikiName, pageName });
    });
}
exports.run = run;
//# sourceMappingURL=page-import.js.map